@@ -121,8 +121,7 @@ class logged_in:
     user = None
     #self.user = log_in.__init__()
     #user = None
-    chatrooms = ["sports", "general", "education", "health", "technology"]
-    #chatrooms = ["Python", "Java", "Php", "C", "Web", "Stacks", "General"]
+    chatrooms = ["Python", "Java", "Php", "C", "Web", "Stacks", "General"]
     def __init__(self):
         print("\n")        
         print(colored("You're logged in   ", "blue"))
